Changelog
=========

0.1.1 (2024-07-19)
------------------

- Handled Windows startup add or remove following parameters.
  [sgeulette]

0.1.0 (2024-07-18)
------------------

- Initial release.
  [sgeulette]
